==> codingtalk-uni-toolkit-0.0.7.tgz: package/src/core/entity.class.js <==
import Request from './request';
import formToolkit from './formToolkit';
import { _cloneDeep, _get, _set } from '../utils/fn';
import CUT from '../cut'

const _baseTableField = {
    id: {
        type: 'int',
        default: 0
    },
    sn: {
        type: 'int',
        default: 0
    },
    status: {
        type: 'int',
        default: 0
    },
    isDelete: {
        type: 'int',
        default: 0
    },
    createTime: {
        type: 'string',
        default: ''
    },
    updateTime: {
        type: 'string',
        default: ''
    },
    deleteTime: {
        type: 'string',
        default: ''
    }
};

class Entity {
    _tableField = []
    request = null
    _raw = null
    constructor(entity, { _tableField }) {
        const { _entityCollection } = CUT;
        this._tableField = Object.assign(_cloneDeep(_baseTableField), _tableField);
        for (const i in this._tableField) {
            if (entity && this._tableField[i].isEntity) {
                const v = _get(entity, i);
                this[i] = Array.isArray(v) ? v.map(j => new _entityCollection[this._tableField[i].type](j)) : new _entityCollection[this._tableField[i].type](v);
                continue;
            }
            this[i] = entity ? this._fieldDo(entity, i) : _get(this._tableField, `${i}.default`);
            this._raw = entity;
        }
    }

    _fieldDo(entity, i) {
        if (!this._tableField[i].do) {
            return _get(entity, i);
        }
        const { parse } = this._tableField[i].do;
        if (parse) {
            return (_get(entity, i) || '{}').toParse();
        }
    }


    static sendApi(method, form = { params: {}, body: {} }, config = { errorTip: '', parse4Entity: false, showLoading: false }) {
        const { app, domain } = this._requestConfig;
        return new Request().do(app, domain, method, form, { showLoading: config.showLoading }).then(res => {
            const { status } = res;
            if (!status && config.errorTip) {
                if (typeof config.errorTip === 'function') {
                    config.errorTip(res);
                } else {

                }
            }
            if (config.parse4Entity) {
                res.data = Array.isArray(res.data) ? res.data.map(i => new this(i)) : new this(res.data);
            }
            return res;
        });
    }

    static formUtil() {
        return {
            generator: (module, type) => {
                const f = _get(this._form, `${module}.${type}`);
                for (const i in f) {
                    f[i] = Object.assign(f[i], { _validator: { ok: true, msg: '' } });
                }
                return {
                    ..._cloneDeep(f),
                    FILED(s) {
                        const _self = this;
                        let k = '';
                        const sr = s.split('.');
                        for (let i in sr) {
                            const r = sr[i].match(/(\S+)\[(\d+)\]$/);
                            if (r && r.length === 3) {
                                k = k + `${r[1]}.value[${r[2]}]`
                                continue;
                            }
                            k = k + (i == sr.length - 1 ? `${sr[i]}.value` : `${sr[i]}.value.`)
                        }
                        return {
                            get val() {
                                return _get(_self, k);
                            },
                            set val(v) {
                                _set(_self, k, v);
                            },
                            get valid() {
                                return _get(_self, k.slice(0, k.length - 6));
                            }
                        };
                    }
                };
            },
            validate: (json) => {
                return formToolkit.validate(json);
            },
            fill: (f, json, config) => {
                for (const i in f) {
                    f[i] = Object.assign(f[i], { _validator: { ok: true, msg: '' } });
                }
                return formToolkit.fill(f, json, config);
            }
        };
    }

}

export default Entity;

==> codingtalk-uni-toolkit-0.0.28.tgz: package/src/core/entity.class.js <==
import Request from './request';
import formToolkit from './formToolkit';
import { _cloneDeep, _get, _set } from '../utils/fn';
import global from '../global'

const _baseTableField = {
    id: {
        type: 'int',
        default: 0
    },
    sn: {
        type: 'int',
        default: 0
    },
    status: {
        type: 'int',
        default: 0
    },
    isDelete: {
        type: 'int',
        default: 0
    },
    createTime: {
        type: 'string',
        default: ''
    },
    updateTime: {
        type: 'string',
        default: ''
    },
    deleteTime: {
        type: 'string',
        default: ''
    }
};

class Entity {
    _tableField = []
    request = null
    _raw = null
    constructor(entity, { _tableField }) {
        const { _entityCollection } = global;
        this._tableField = Object.assign(_cloneDeep(_baseTableField), _tableField);
        for (const i in this._tableField) {
            if (entity && this._tableField[i].isEntity) {
                const v = _get(entity, i);
                this[i] = Array.isArray(v) ? v.map(j => new _entityCollection[this._tableField[i].type](j)) : new _entityCollection[this._tableField[i].type](v);
                continue;
            }
            this[i] = entity ? this._fieldDo(entity, i) : _get(this._tableField, `${i}.default`);
            this._raw = entity;
        }
    }

    _fieldDo(entity, i) {
        if (!this._tableField[i].do) {
            return _get(entity, i);
        }
        const { parse } = this._tableField[i].do;
        if (parse) {
            return (_get(entity, i) || '{}').toParse();
        }
    }


    static sendApi(method, form = { params: {}, body: {} }, config = { errorTip: '', parse4Entity: false, showLoading: false }) {
        const { app, domain } = this._requestConfig;
        return new Request().do(app, domain, method, form, { showLoading: config.showLoading }).then(res => {
            const { status } = res;
            if (!status && config.errorTip) {
                if (typeof config.errorTip === 'function') {
                    config.errorTip(res);
                } else {

                }
            }
            if (config.parse4Entity) {
                res.data = Array.isArray(res.data) ? res.data.map(i => new this(i)) : new this(res.data);
            }
            return res;
        });
    }

    static formUtil() {
        return {
            generator: (module, type) => {
                const f = _get(this._form, `${module}.${type}`);
                for (const i in f) {
                    f[i] = Object.assign(f[i], { _validator: { ok: true, msg: '' } });
                }
                return {
                    ..._cloneDeep(f),
                    FILED(s) {
                        const _self = this;
                        let k = '';
                        const sr = s.split('.');
                        for (let i in sr) {
                            const r = sr[i].match(/(\S+)\[(\d+)\]$/);
                            if (r && r.length === 3) {
                                k = k + `${r[1]}.value[${r[2]}]`
                                continue;
                            }
                            k = k + (i == sr.length - 1 ? `${sr[i]}.value` : `${sr[i]}.value.`)
                        }
                        return {
                            get val() {
                                return _get(_self, k);
                            },
                            set val(v) {
                                _set(_self, k, v);
                            },
                            get valid() {
                                return _get(_self, k.slice(0, k.length - 6));
                            }
                        };
                    }
                };
            },
            validate: (json) => {
                return formToolkit.validate(json);
            },
            fill: (f, json, config) => {
                for (const i in f) {
                    f[i] = Object.assign(f[i], { _validator: { ok: true, msg: '' } });
                }
                return formToolkit.fill(f, json, config);
            }
        };
    }

}

export default Entity;
